@@ -1,6 +1,6 @@
 ;;; r7rs compatibility
 
-(require cload.scm libc.scm stuff.scm)
+(require libc.scm stuff.scm)
 (provide 'r7rs.scm)
 
 
@@ -47,9 +47,8 @@
 (define bytevector byte-vector)
 (define bytevector? byte-vector?)
 (define make-bytevector make-byte-vector)
-(define bytevector-ref string-ref)
-(define bytevector-set! string-set!)
-
+(define bytevector-ref byte-vector-ref)
+(define bytevector-set! byte-vector-set!)
 (define bytevector-copy! vector-copy!)
 (define string-copy! vector-copy!)
 (define (bytevector->list bv) (map values bv))
@@ -75,10 +74,7 @@
 (define (digit-value c) (and (char-numeric? c) (- (char->integer c) (char->integer #\0))))
 
 
-(define +inf.0 inf.0)
-(define +nan.0 nan.0)
 (define (finite? n) (and (number? n) (not (nan? n)) (not (infinite? n))))
-
 (define exact-integer? integer?)	
 (define (exact-integer-sqrt i) (let ((sq (floor (sqrt i)))) (values sq (- i (* sq sq)))))
 (define inexact exact->inexact)
@@ -101,13 +97,13 @@
 (define (call-with-port port proc) ((if (input-port? port) call-with-input-file call-with-output-file) port proc))
 
 
-(define (bytevector-u8-ref b k) (b k))
-(define (bytevector-u8-set! b k c) (set! (b k) c))
+(define bytevector-u8-ref byte-vector-ref)
+(define bytevector-u8-set! byte-vector-set!)
 (define bytevector-u8 (dilambda (lambda (b k) (b k)) (lambda (b k c) (set! (b k) c))))
 (define bytevector-length length)
-(define (bytevector-copy . args) (string->byte-vector (apply r7rs-string-copy args)))
-(define (bytevector-append . args) (string->byte-vector (apply string-append args)))
-(define write-bytevector write-string)
+(define bytevector-copy vector-copy!)
+(define bytevector-append append)
+(define write-bytevector write)
 (define* (read-bytevector! bv port (start 0) end)
   (let ((lim (or end (length bv)))
 	(pt (or port (current-input-port))))
@@ -118,7 +114,7 @@
 	 bv)
       (set! (bv i) c))))
 (define* (read-bytevector k port)
-  (read-bytevector! (string->byte-vector (make-string k)) port))
+  (read-bytevector! (make-byte-vector k) port))
 (define (get-output-bytevector port) (string->byte-vector (get-output-string port)))
 (define open-input-bytevector open-input-string)
 (define open-output-bytevector open-output-string)
@@ -126,8 +122,14 @@
 (define write-u8 write-byte) 
 (define u8-ready? char-ready?) 
 (define peek-u8 peek-char)
-(define* (utf8->string v (start 0) end) (substring v start (or end (length v))))
-(define* (string->utf8 s (start 0) end) (string->byte-vector (utf8->string s start end)))
+(define* (utf8->string v (start 0) end) 
+  (if (string? v)
+      v
+      (substring (byte-vector->string v) start (or end (length v)))))
+(define* (string->utf8 s (start 0) end) 
+  (if (byte-vector? s)
+      s
+      (string->byte-vector (utf8->string s start end))))
 (define write-simple write)
 
 (define (eof-object) #<eof>)
@@ -360,29 +362,9 @@
 ;; and why no euclidean-rationalize or exact-integer-expt?
 ;;   (imagine what will happen when r8rs stumbles on the zoo of continued fraction algorithms!)
 
-(let ((e (curlet)))
-  (c-define 
-    '((in-C "static int g_time(void) {return((int)time(NULL));} \n\
-             static struct timeval overall_start_time;  \n\
-             static bool time_set_up = false;           \n\
-             static double get_internal_real_time(void) \n\
-             {                                          \n\
-               struct timezone z0;                      \n\
-               struct timeval t0;                       \n\
-               double secs;                             \n\
-               if (!time_set_up) {gettimeofday(&overall_start_time, &z0); time_set_up = true;} \n\
-               gettimeofday(&t0, &z0);                  \n\
-               secs = difftime(t0.tv_sec, overall_start_time.tv_sec);\n\
-               return(secs + 0.000001 * (t0.tv_usec - overall_start_time.tv_usec)); \n\
-             }")
-      (double get_internal_real_time (void))
-      (int g_time (void)))
-    "" '("time.h" "sys/time.h"))
-  (varlet e 
-    (cons 'jiffies-per-second (lambda () 1000))
-    (cons 'current-jiffy (lambda () (round (* (get_internal_real_time) 1000.0))))
-    (cons 'current-second g_time)))
-
+(define (jiffies-per-second) 1000)
+(define (current-jiffy) (round (* (jiffies-per-second) (*s7* 'cpu-time))))
+(define (current-second) (floor (*s7* 'cpu-time)))
 
 (define (get-environment-variable x)
   (let ((val ((*libc* 'getenv) x)))
