@@ -73,7 +73,11 @@ static gboolean listener_key_press(GtkWidget *w, GdkEventKey *event, gpointer da
   /* glistener_clear_status(ss->listener); */
 
   key = EVENT_KEYVAL(event);
-  state = (GdkModifierType)EVENT_STATE(event);
+#if (GTK_CHECK_VERSION(3, 0, 0))
+  gdk_event_get_state((GdkEvent *)event, &state);
+#else
+  state = event->state;
+#endif
 
   if ((state & snd_ControlMask) &&
       ((key == snd_K_g) || (key == snd_K_G)))
@@ -151,7 +155,7 @@ static const char *helper(glistener *g, const char *text)
 #if HAVE_CHECKER
 static const char *checker(glistener *g, const char *text)
 {
-  int gc_loc, err_loc;
+  s7_int gc_loc, err_loc;
   s7_pointer port, err_port, result;
   const char *errmsg;
   bool err = false;
@@ -360,7 +364,7 @@ static s7_pointer g_set_top_level_let(s7_scheme *sc, s7_pointer args)
 
 static void evaluator(glistener *g, const char *text)
 {
-  unsigned int gc_loc;
+  s7_int gc_loc;
   s7_pointer old_port, result;
   char *errmsg = NULL;
   
@@ -579,15 +583,22 @@ static void evaluator(glistener *g, const char *text)
 }
 #endif
 
-
+#if (GTK_CHECK_VERSION(3, 92, 1))
+static bool keyer(glistener *g, GtkWidget *w, GdkEvent *e)
+#else
 static bool keyer(glistener *g, GtkWidget *w, GdkEventKey *e)
+#endif
 {
   /* add C-g handling */
   guint key;
   GdkModifierType state;
 
   key = EVENT_KEYVAL(e);
-  state = (GdkModifierType)EVENT_STATE(e);
+#if (GTK_CHECK_VERSION(3, 0, 0))
+  gdk_event_get_state((GdkEvent *)e, &state);
+#else
+  state = e->state;
+#endif
   if (((key == snd_K_g) || (key == snd_K_G)) &&
       (state & snd_ControlMask))
     {
