@@ -751,9 +751,6 @@
 		    "(make-hook)" "(make-hook '__x__)"
 		    "1+i" "0+i" "(ash 1 43)" 
 		    "(integer->char 255)" "(string (integer->char 255))" "(string #\\null)" "(byte-vector 0)"
-		    ;;"most-positive-fixnum" "most-negative-fixnum"
-		    ;;"(/ 1 most-positive-fixnum)" "(complex most-negative-fixnum most-negative-fixnum)" 
-		    ;;"(/ most-negative-fixnum most-positive-fixnum)"
 		    "pi" "+nan.0" "+inf.0" "-inf.0" "-nan.0"
 		    "(list)" "(string)" "#r()" "#u()" "(vector)" "#i()" "(make-iterator #(10 20))" "#i(1)"
 		    "0" "1" "4" "1.0" "-1.0" "1.0+123.0i" "3/4" "(make-vector 3)" "(make-string 3 #\\space)" "(make-vector '(2 3))"
@@ -888,7 +885,7 @@
 		    "(make-vector '(2 3) 1)"             "(make-vector '(12 14) #<undefined>)"
 		    "(make-byte-vector '(2 3) 1)"        "(make-byte-vector '(4 32) 255)"
 		    "(make-string 256 #\\1)"             "(make-string 1024 #\\null)"
-		    "(make-int-vector '(2 3) 1)"         "(make-int-vector '(2 128) most-negative-fixnum)"
+		    "(make-int-vector '(2 3) 1)"         "(make-int-vector '(2 128) (*s7* 'most-negative-fixnum))"
 		    "(make-float-vector '(2 3) 1)"       "(make-float-vector '(128 3) pi)"
 		    "(make-vector 3 'a symbol?)"         "(make-vector '(2 3 4 3 2 3 4) 1)"
 		    "(make-vector 3 1+i complex?)"       "(make-vector (make-list 10 2))"
