@@ -1,10 +1,12 @@
 ;;; cyclic/shared timing tests
 
+(set! (*s7* 'heap-size) (* 2 1024000))
+
 ;;; equal? write/object->string/format cyclic-sequences
 
 (define* (make-circular-list n init)
-  (let ((l (make-list n init)))
-    (set-cdr! (list-tail l (- n 1)) l)))
+  (let ((lst (make-list n init)))
+    (set-cdr! (list-tail lst (- n 1)) lst)))
 
 (define list-0 (list 1 2 3 4))
 (define vect-0 (vector 1 2 3 4))
@@ -18,14 +20,13 @@
 (define let-1 (inlet :a list-1))
 (define list-2 (list list-1 list-1))
 (define list-3 (make-circular-list 3))
-(define vect-2 (let ((z (vector 1 2)))
-		 (let ((y (list 1 z 2)))
-		   (let ((x (hash-table 'x y)))
-		     (set! (z 1) x)
-		     z))))
+(define vect-2 (let* ((z (vector 1 2))
+		      (y (list 1 z 2))
+		      (x (hash-table 'x y)))
+		 (set! (z 1) x)
+		 z))
 (define vect-3 (let ((x '(1 2)))
-		 (let ((y (list x x)))
-		   (vector x y))))
+		 (vector x (list x x))))
 (define vect-4 (let ((v (vector 1 2 3 4))
 		     (lst (list 1 2)))
 		 (set-cdr! (cdr lst) lst)
@@ -53,10 +54,10 @@
 		(let ((e (curlet)))
 		  (set! hi (curlet)) 
 		  e)))
-(define let-3 (let ((e (inlet 'a 0 'b 1)))
-		(let ((e1 (inlet 'a e)))
-		  (set! (e 'b) e1)
-		  e)))
+(define let-3 (let* ((e (inlet 'a 0 'b 1))
+		     (e1 (inlet 'a e)))
+		(set! (e 'b) e1)
+		e))
 (define let-4 (inlet :a vect-0 :b list-0))
 (define hash-3 (hash-table :a vect-0 :b list-0))
 (define hash-4 (hash-table :a hash-1))
@@ -69,35 +70,12 @@
 ;(format *stderr* "~A ~A ~A ~A ~A~%" (length hash-0) (length hash-1) (length hash-2) (length hash-3) (length hash-4))
 
 (set! (*s7* 'initial-string-port-length) 64)
-#|
-(define (tests size)
-  (let ((str #f)
-	(p (open-output-string))
-	(iter #f))
-    (do ((i 0 (+ i 1)))
-	((= i size))
-      (set! iter (make-iterator teq-vars))
-      (do ((j 0 (+ j 1))
-	   (vj (iterate iter) (iterate iter)))
-	  ((= j 20))
-	(do ((k 0 (+ k 1)))
-	    ((= k 20))
-	  (if (equal? vj (vector-ref teq-vars k))
-	      (if (not (= j k))
-		  (format *stderr* "oops! (~D ~D): ~A ~A~%" j k vj (vector-ref teq-vars k)))))
-	(write vj p)
-	(set! str (get-output-string p #t))
-	(set! str (object->string vj))
-	(set! str (format #f "~A~%" vj))
-	(set! str (cyclic-sequences vj))))
-    (close-output-port p)))
-|#
 
 (define (tests size)
   (let ((str #f)
 	(vj #f)
 	(p (open-output-string)))
-    (do ((i 0 (+ i 1)))
+    (do ((i 0 (+ i 1)))                 ; nested for-each is almost as fast
 	((= i size))
       (do ((a teq-vars (cdr a)))
 	  ((null? a))
@@ -106,48 +84,14 @@
 	    ((null? b))
 	  (if (equal? vj (car b))
 	      (if (not (eq? a b))
-		  (format *stderr* "oops!: ~A ~A~%"  a b))))
+		  (format *stderr* "oops!: ~A ~A~%" a b))))
 	(write vj p)
-	(set! str (get-output-string p #t))
-	(set! str (object->string vj))
-	(set! str (format #f "~A~%" vj))
-	(set! str (cyclic-sequences vj))))
+	(get-output-string p #t)
+	(object->string vj)
+	(format #f "~A~%" vj)
+	(cyclic-sequences vj)))
     (close-output-port p)))
-#|
-;; almost as fast
-(define (tests size)
-  (let ((str #f)
-	(p (open-output-string))
-	(k 0) (j 0))
-    (do ((i 0 (+ i 1)))
-	((= i size))
-      (set! k 0)
-      (for-each 
-       (lambda (vj)
-	 (set! j 0)
-	 (for-each 
-	  (lambda (w)
-	    (if (equal? vj w)
-		(if (not (= j k))
-		    (format *stderr* "oops! (~D ~D): ~A ~A~%" j k vj w)))
-	    (set! j (+ j 1)))
-	  teq-vars)
-	 (set! k (+ k 1))
-	 (write vj p)
-	 (set! str (get-output-string p #t))
-	 (set! str (object->string vj))
-	 (set! str (format #f "~A~%" vj))
-	 (set! str (cyclic-sequences vj)))
-       teq-vars))
-    (close-output-port p)))
-|#
-
 
 (tests 10000)
 
-(s7-version)
 (exit)
-
-
-
-	
