@@ -1,4 +1,4 @@
-(set! (*s7* 'heap-size) (* 6 1024000))
+(set! (*s7* 'heap-size) (* 5 1024000))
 ;(set! (*s7* 'gc-stats) 6)
 
 (define (reader)
@@ -28,9 +28,9 @@
 			     (<= k start))
 			 (+ k 1)))))
 	  (when (> end start)
-	    (let ((word (string->symbol (substring line start end))))
-	      (let ((refs (or (hash-table-ref counts word) 0)))
-		(hash-table-set! counts word (+ refs 1))))))
+	    (let* ((word (string->symbol (substring line start end)))
+		   (refs (or (hash-table-ref counts word) 0)))
+	      (hash-table-set! counts word (+ refs 1)))))
 	(set! new-pos (+ pos 1))))
     
     (close-input-port port)
@@ -50,6 +50,49 @@
 
 ;;; ----------------------------------------
 
+(let ()
+  (define (walk p counts)
+    (if (pair? p)
+	(begin
+	  (walk (car p) counts)
+	  (if (pair? (cdr p))
+	      (walk (cdr p) counts)))
+	(hash-table-set! counts p (+ (or (hash-table-ref counts p) 0) 1))))
+  
+  (define (s7test-reader)
+    (let ((port (open-input-file "/home/bil/cl/s7test.scm"))
+	  (counts (make-hash-table)))
+      (do ((expr (read port) (read port)))
+	  ((eof-object? expr) 
+	   counts)
+	(walk expr counts))))
+  
+  (define (sort-counts counts)
+    (let ((len (hash-table-entries counts)))
+      (do ((v (make-vector len))
+	   (h (make-iterator counts))
+	   (i 0 (+ i 1)))
+	  ((= i len)
+	   (sort! v (lambda (e1 e2) (> (cdr e1) (cdr e2))))
+	   v)
+	(vector-set! v i (iterate h)))))
+  
+  (sort-counts (s7test-reader)))
+
+;;; ----------------------------------------
+
+(let ()
+  (define (hash-ints)
+    (let ((counts (make-hash-table 8 = (cons integer? integer?))))
+      (do ((i 0 (+ i 1))
+	   (z (random 100) (random 100)))
+	  ((= i 5000000) counts)
+	(hash-table-set! counts z (+ (or (hash-table-ref counts z) 0) 1)))))
+
+  (hash-ints))
+
+;;; ----------------------------------------
+
 (define symbols (make-vector 1))
 (define strings (make-vector 1))
 
@@ -125,7 +168,7 @@
     (set! sym-hash #f)))
 
 (define (test7 size)
-  (let ((chr-hash (make-hash-table 256)))
+  (let ((chr-hash (make-hash-table 256 char=?)))
     (do ((i 0 (+ i 1))) 
 	((= i 256)) 
       (hash-table-set! chr-hash (integer->char i) i))
@@ -139,11 +182,13 @@
   (let ((any-hash (make-hash-table size eq?)))
     (if (= size 1)
 	(hash-table-set! any-hash (vector-set! strings 0 (list 0)) 0)
-	(do ((i 0 (+ i 2))
-	     (j 1 (+ j 2)))
-	    ((= i size))
-	  (hash-table-set! any-hash (vector-set! strings i (list i)) i)
-	  (hash-table-set! any-hash (vector-set! strings j (int-vector j)) j)))
+	(begin
+	  (do ((i 0 (+ i 2)))
+	      ((= i size))
+	    (hash-table-set! any-hash (vector-set! strings i (list i)) i))
+	  (do ((j 1 (+ j 2)))
+	      ((>= j size))
+	    (hash-table-set! any-hash (vector-set! strings j (int-vector j)) j))))
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= i (hash-table-ref any-hash (vector-ref strings i))))
@@ -154,12 +199,14 @@
   (let ((any-hash1 (make-hash-table size eq?)))
     (if (= size 1)
 	(hash-table-set! any-hash1 (vector-set! strings 0 (inlet 'a 0)) 0)
-	(do ((i 0 (+ i 2))
-	     (j 1 (+ j 2))
-	     (x 0.0 (+ x 2.0)))
-	    ((= i size))
-	  (hash-table-set! any-hash1 (vector-set! strings i (inlet 'a i)) i)
-	  (hash-table-set! any-hash1 (vector-set! strings j (float-vector x)) j)))
+	(begin
+	  (do ((i 0 (+ i 2)))
+	      ((= i size))
+	    (hash-table-set! any-hash1 (vector-set! strings i (inlet 'a i)) i))
+	  (do ((j 1 (+ j 2))
+	       (x 0.0 (+ x 2.0)))
+	      ((>= j size))
+	    (hash-table-set! any-hash1 (vector-set! strings j (float-vector x)) j))))
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (if (not (= i (hash-table-ref any-hash1 (vector-ref strings i))))
@@ -168,7 +215,7 @@
     (set! any-hash1 #f)))
 
 (define (test10 size)
-  (let ((cmp-hash (make-hash-table size)))
+  (let ((cmp-hash (make-hash-table size =)))
     (do ((i 0 (+ i 1))) 
 	((= i size)) 
       (hash-table-set! cmp-hash (complex i i) i))
@@ -196,5 +243,4 @@
 (for-each test-hash (list 1 10 100 1000 10000 100000 1000000))
 (newline)
 
-(s7-version)
 (exit)
