@@ -337,10 +337,10 @@
 	  (primes (make-vector 129)))
       (do ((i 2 (+ i 1)))
 	  ((> i 128))
-	(set! (alls i) (min-peak :all i))
-	(set! (odds i) (min-peak :odd i))
-	(set! (evens i) (min-peak :even i))
-	(set! (primes i) (min-peak :prime i)))
+	(vector-set! alls i (min-peak :all i))
+	(vector-set! odds i (min-peak :odd i))
+	(vector-set! evens i (min-peak :even i))
+	(vector-set! primes i (min-peak :prime i)))
 
       (load previous-version)
       (do ((i 2 (+ i 1)))
@@ -349,14 +349,13 @@
 	      (old-odd (min-peak :odd i))
 	      (old-even (min-peak :even i))
 	      (old-prime (min-peak :prime i)))
-	  (if (< old-all (alls i)) (format () ":all ~D: ~A to ~A~%" i old-all (alls i)))
-	  (if (< old-odd (odds i)) (format () ":odd ~D: ~A to ~A~%" i old-odd (odds i)))
-	  (if (< old-even (evens i)) (format () ":even ~D: ~A to ~A~%" i old-even (evens i)))
-	  (if (< old-prime (primes i)) (format () ":prime ~D: ~A to ~A~%" i old-prime (primes i))))))))
+	  (if (< old-all (vector-ref alls i)) (format () ":all ~D: ~A to ~A~%" i old-all (alls i)))
+	  (if (< old-odd (vector-ref odds i)) (format () ":odd ~D: ~A to ~A~%" i old-odd (odds i)))
+	  (if (< old-even (vector-ref evens i)) (format () ":even ~D: ~A to ~A~%" i old-even (evens i)))
+	  (if (< old-prime (vector-ref primes i)) (format () ":prime ~D: ~A to ~A~%" i old-prime (primes i))))))))
 
 
 (base-case)
 (checks)
 
-(s7-version)
 (exit)
