@@ -3,6 +3,7 @@
 
 (set! (*s7* 'print-length) 8) ; :readable should ignore this
 (set! (*s7* 'default-hash-table-length) 4)
+(set! (*s7* 'heap-size) (* 10 1024000))
 
 (define (tester)
   (do ((baddies 0)
@@ -103,13 +104,13 @@
 				       ((3) (format #f "~W" (cadr set)))
 				       ((4) (symbol->keyword (cadr set))))
 				     (#(p v cy h e it cp) (caddr set))))
-			      ((= (car set) 5)
-			       (format *stderr* "  (set! ((iterator-sequence it) ~A) ~A)~%" 
-				       (cadr set) 
-				       (#(p v cy h e it cp) (caddr set))))
-			      (else (format *stderr* "  (set! (((object->let cp) 'c-type) ~A) ~A)~%" 
-					    (cadr set)
-					    (#(p v cy h e it cp) (caddr set))))))
+			    ((= (car set) 5)
+			     (format *stderr* "  (set! ((iterator-sequence it) ~A) ~A)~%" 
+				     (cadr set) 
+				     (#(p v cy h e it cp) (caddr set))))
+			    (else (format *stderr* "  (set! (((object->let cp) 'c-type) ~A) ~A)~%" 
+					  (cadr set)
+					  (#(p v cy h e it cp) (caddr set))))))
 		    sets)
 		   (format *stderr* "  ~A)~%" (#(p v cy h e it cp) bi)))
 		 (set! bi (+ bi 1))))
@@ -117,7 +118,4 @@
 
 (tester)
 
-  
-  
-(s7-version)
 (exit)
