@@ -1,4 +1,5 @@
-;(set! (*s7* 'heap-size) (* 4 1024000))
+(set! (*s7* 'heap-size) (* 4 1024000))
+
 (if (not (defined? 'unless))
     (define-macro (unless test . body)
       `(if (not ,test) (begin ,@body))))
@@ -44,6 +45,9 @@
            b
            (tfib (- n 1) b (+ a b)))))
 
+;;; overflow at (tfib 92): (tfib 92) 12200160415121877000.0, (tfib 91) 7540113804746346429 [this numbering is off-by-1]
+;;;                              93: 12200160415121876738          92: 7540113804746346429 http://www.maths.surrey.ac.uk/hosted-sites/R.Knott/Fibonacci/fibtable.html
+
 (let ((f32 (tfib 31)))
   (unless (= f32 2178309)
     (format *stderr* "tfib ~A~%" f32)))
@@ -139,16 +143,19 @@
 (more-add)
 
 
-(define* (adder lst (sum 0))
-  (if (pair? lst)
-      (adder (cdr lst) (+ sum (car lst)))
-      sum))
+(define (adder lst)
+  (letrec ((add (lambda (L sum)
+		  (if (pair? L)
+		      (add (cdr L) (+ sum (car L)))
+		      sum))))
+    (add lst 0)))
 
 (define (more-adder)
-  (let ((lst big-list))
-    (do ((i 0 (+ i 1)))
-	((= i 1000))
-      (adder lst 0))))
+  (do ((lst big-list)
+       (i 0 (+ i 1)))
+      ((= i 1000))
+    (adder big-list)))
+
 (more-adder)
 
 
@@ -177,12 +184,12 @@
   (unless (= n 2045)
     (format *stderr* "ack ~A~%" n)))
 
-(define-constant (tree-eq? a b)
-  (if (pair? a)
+(define (tree-eq? a b)
+  (if (not (pair? a))
+      (eq? a b)
       (and (pair? b)
 	   (tree-eq? (car a) (car b))
-	   (tree-eq? (cdr a) (cdr b)))
-      (eq? a b)))
+	   (tree-eq? (cdr a) (cdr b)))))
 
 (define tree '((a b) (c d e) (f) () (g h i j) (k (l m (n o)) p) (q ((r) s) (((t (u) v) w) x) y) z))
 (define (more-eq)
