@@ -214,7 +214,7 @@
 	(sum 0))
     (do ((i 0 (+ i 1)))
 	((= i size) sum)
-      (set! sum (+ sum (if (zero? (real-part (v i))) 1 0))))))
+      (set! sum (+ sum (if (zero? (real-part (vector-ref v i))) 1 0)))))) ; faster is (imag-part...)
 
 (unless (= (g6) size)
   (format *stderr* "g6: ~S~%" (g6)))
@@ -294,7 +294,7 @@
 	((= k 10) sum)
       (do ((i 0 (+ i 1)))
 	  ((= i size/10))
-	(set! sum (+ sum (if (char=? (v k i) #\a) 1 0)))))))
+	(set! sum (+ sum (if (char=? (vector-ref v k i) #\a) 1 0)))))))
 
 (unless (= (g16) size)
   (format *stderr* "g16: ~S~%" (g16)))
@@ -760,8 +760,20 @@
 (unless (= (sum-f1111) 7812437500.0)
   (format *stderr* "f1111: ~S~%" (sum-f1111)))
 
+(define (vcop a b n)
+  (let ((c (do ((i (- n 1) (- i 1)))
+	       ((< i 0) b)
+	     (vector-set! b i (vector-ref a i)))))
+    (do ((i 0 (+ i 1)))
+	((= i n) a)
+      (vector-set! a i (vector-ref b i)))))
 
+(define (tvcop)
+  (do ((k 0 (+ k 1)))
+      ((= k 1000))
+    (vcop (make-vector 1000 1) (make-vector 1000 0) 1000)))
+
+(tvcop)
 
-(s7-version)
 (exit)
 
